@@ -1,4 +1,4 @@
 __all__ = ['Genome', 'Chromosome', 'Gene', 'Transcript', 'Exon', 'Protein', 'SNP']
 
-from configuration import *
+from configuration import pyGeno_init
 pyGeno_init()
